summaryrefslogtreecommitdiffstats
path: root/kdeprint/kdeprintfax
diff options
context:
space:
mode:
Diffstat (limited to 'kdeprint/kdeprintfax')
-rw-r--r--kdeprint/kdeprintfax/CMakeLists.txt18
-rw-r--r--kdeprint/kdeprintfax/Makefile.am24
-rwxr-xr-xkdeprint/kdeprintfax/anytops4
-rw-r--r--kdeprint/kdeprintfax/conffax.cpp2
-rw-r--r--kdeprint/kdeprintfax/conffax.h2
-rw-r--r--kdeprint/kdeprintfax/conffilters.cpp6
-rw-r--r--kdeprint/kdeprintfax/conffilters.h2
-rw-r--r--kdeprint/kdeprintfax/confgeneral.cpp2
-rw-r--r--kdeprint/kdeprintfax/confgeneral.h2
-rw-r--r--kdeprint/kdeprintfax/configdlg.cpp4
-rw-r--r--kdeprint/kdeprintfax/configdlg.h2
-rw-r--r--kdeprint/kdeprintfax/confsystem.cpp2
-rw-r--r--kdeprint/kdeprintfax/confsystem.h2
-rw-r--r--kdeprint/kdeprintfax/defcmds.cpp2
-rw-r--r--kdeprint/kdeprintfax/defcmds.h2
-rw-r--r--kdeprint/kdeprintfax/faxab.cpp2
-rw-r--r--kdeprint/kdeprintfax/faxab.h2
-rw-r--r--kdeprint/kdeprintfax/faxctrl.cpp8
-rw-r--r--kdeprint/kdeprintfax/faxctrl.h4
-rw-r--r--kdeprint/kdeprintfax/filterdlg.cpp2
-rw-r--r--kdeprint/kdeprintfax/filterdlg.h2
-rw-r--r--kdeprint/kdeprintfax/kdeprintfax.cpp8
-rw-r--r--kdeprint/kdeprintfax/kdeprintfax.desktop4
-rw-r--r--kdeprint/kdeprintfax/kdeprintfax.h2
-rw-r--r--kdeprint/kdeprintfax/kdeprintfaxui.rc2
-rw-r--r--kdeprint/kdeprintfax/main.cpp10
26 files changed, 61 insertions, 61 deletions
diff --git a/kdeprint/kdeprintfax/CMakeLists.txt b/kdeprint/kdeprintfax/CMakeLists.txt
index 9c6e5095f..538719474 100644
--- a/kdeprint/kdeprintfax/CMakeLists.txt
+++ b/kdeprint/kdeprintfax/CMakeLists.txt
@@ -22,21 +22,21 @@ link_directories(
##### other data ################################
-tde_install_icons( kdeprintfax )
-tde_install_icons( abentry DESTINATION ${DATA_INSTALL_DIR}/kdeprintfax/icons )
-install( FILES kdeprintfax.desktop DESTINATION ${XDG_APPS_INSTALL_DIR} )
-install( FILES kdeprintfaxui.rc faxfilters DESTINATION ${DATA_INSTALL_DIR}/kdeprintfax )
-install( PROGRAMS anytops DESTINATION ${DATA_INSTALL_DIR}/kdeprintfax )
+tde_install_icons( tdeprintfax )
+tde_install_icons( abentry DESTINATION ${DATA_INSTALL_DIR}/tdeprintfax/icons )
+install( FILES tdeprintfax.desktop DESTINATION ${XDG_APPS_INSTALL_DIR} )
+install( FILES tdeprintfaxui.rc faxfilters DESTINATION ${DATA_INSTALL_DIR}/tdeprintfax )
+install( PROGRAMS anytops DESTINATION ${DATA_INSTALL_DIR}/tdeprintfax )
-##### kdeprintfax (executable) ##################
+##### tdeprintfax (executable) ##################
-tde_add_executable( kdeprintfax AUTOMOC
+tde_add_executable( tdeprintfax AUTOMOC
SOURCES
- main.cpp kdeprintfax.cpp faxab.cpp faxctrl.cpp
+ main.cpp tdeprintfax.cpp faxab.cpp faxctrl.cpp
confgeneral.cpp configdlg.cpp conffax.cpp
confsystem.cpp conffilters.cpp filterdlg.cpp
defcmds.cpp
- LINK kabc-shared kdeprint-shared
+ LINK kabc-shared tdeprint-shared
DESTINATION ${BIN_INSTALL_DIR}
)
diff --git a/kdeprint/kdeprintfax/Makefile.am b/kdeprint/kdeprintfax/Makefile.am
index 6685031cb..cd0d39900 100644
--- a/kdeprint/kdeprintfax/Makefile.am
+++ b/kdeprint/kdeprintfax/Makefile.am
@@ -1,23 +1,23 @@
INCLUDES= $(all_includes)
-bin_PROGRAMS = kdeprintfax
-kdeprintfax_SOURCES = main.cpp kdeprintfax.cpp faxab.cpp faxctrl.cpp confgeneral.cpp configdlg.cpp \
+bin_PROGRAMS = tdeprintfax
+tdeprintfax_SOURCES = main.cpp tdeprintfax.cpp faxab.cpp faxctrl.cpp confgeneral.cpp configdlg.cpp \
conffax.cpp confsystem.cpp conffilters.cpp filterdlg.cpp defcmds.cpp
-kdeprintfax_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor
-kdeprintfax_LDADD = $(LIB_KDEUI) $(LIB_KIO) $(LIB_KDEPRINT) -lkabc
-kdeprintfax_METASOURCES = AUTO
+tdeprintfax_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor
+tdeprintfax_LDADD = $(LIB_KDEUI) $(LIB_KIO) $(LIB_KDEPRINT) -lkabc
+tdeprintfax_METASOURCES = AUTO
-xdg_apps_DATA = kdeprintfax.desktop
+xdg_apps_DATA = tdeprintfax.desktop
-uidir = $(kde_datadir)/kdeprintfax
-ui_DATA = kdeprintfaxui.rc faxfilters
+uidir = $(kde_datadir)/tdeprintfax
+ui_DATA = tdeprintfaxui.rc faxfilters
private_SCRIPTS = anytops
-privatedir = $(kde_datadir)/kdeprintfax
+privatedir = $(kde_datadir)/tdeprintfax
messages: rc.cpp
- $(XGETTEXT) `find . -name \*.h -o -name \*.cpp -o -name \*.cc` -o $(podir)/kdeprintfax.pot
+ $(XGETTEXT) `find . -name \*.h -o -name \*.cpp -o -name \*.cc` -o $(podir)/tdeprintfax.pot
-KDE_ICON = kdeprintfax
+KDE_ICON = tdeprintfax
pic_ICON = abentry
-picdir = $(kde_datadir)/kdeprintfax/icons
+picdir = $(kde_datadir)/tdeprintfax/icons
diff --git a/kdeprint/kdeprintfax/anytops b/kdeprint/kdeprintfax/anytops
index 4e67b49e9..9718831dc 100755
--- a/kdeprint/kdeprintfax/anytops
+++ b/kdeprint/kdeprintfax/anytops
@@ -29,8 +29,8 @@ while true; do
shift
;;
-v)
- echo "Anytops v1.0: (c) 2001, Michael Goffioul <kdeprint@swing.be>";
- echo "Small script to convert any file type into PS. Part of kdeprintfax."
+ echo "Anytops v1.0: (c) 2001, Michael Goffioul <tdeprint@swing.be>";
+ echo "Small script to convert any file type into PS. Part of tdeprintfax."
exit 0
;;
*)
diff --git a/kdeprint/kdeprintfax/conffax.cpp b/kdeprint/kdeprintfax/conffax.cpp
index ca6b0d180..1f3b8c3c5 100644
--- a/kdeprint/kdeprintfax/conffax.cpp
+++ b/kdeprint/kdeprintfax/conffax.cpp
@@ -1,5 +1,5 @@
/*
- * kdeprintfax - a small fax utility
+ * tdeprintfax - a small fax utility
* Copyright (C) 2001 Michael Goffioul
*
* This program is free software; you can redistribute it and/or modify
diff --git a/kdeprint/kdeprintfax/conffax.h b/kdeprint/kdeprintfax/conffax.h
index bf31c2990..cf76f2b71 100644
--- a/kdeprint/kdeprintfax/conffax.h
+++ b/kdeprint/kdeprintfax/conffax.h
@@ -1,5 +1,5 @@
/*
- * kdeprintfax - a small fax utility
+ * tdeprintfax - a small fax utility
* Copyright (C) 2001 Michael Goffioul
*
* This program is free software; you can redistribute it and/or modify
diff --git a/kdeprint/kdeprintfax/conffilters.h b/kdeprint/kdeprintfax/conffilters.h
index c4eb1f5c2..871b44bec 100644
--- a/kdeprint/kdeprintfax/conffilters.h
+++ b/kdeprint/kdeprintfax/conffilters.h
@@ -1,5 +1,5 @@
/*
- * kdeprintfax - a small fax utility
+ * tdeprintfax - a small fax utility
* Copyright (C) 2001 Michael Goffioul
*
* This program is free software; you can redistribute it and/or modify
diff --git a/kdeprint/kdeprintfax/confgeneral.cpp b/kdeprint/kdeprintfax/confgeneral.cpp
index a7d8ac3e7..db3ef916a 100644
--- a/kdeprint/kdeprintfax/confgeneral.cpp
+++ b/kdeprint/kdeprintfax/confgeneral.cpp
@@ -1,5 +1,5 @@
/*
- * kdeprintfax - a small fax utility
+ * tdeprintfax - a small fax utility
* Copyright (C) 2001 Michael Goffioul
*
* This program is free software; you can redistribute it and/or modify
diff --git a/kdeprint/kdeprintfax/confgeneral.h b/kdeprint/kdeprintfax/confgeneral.h
index e94ac7422..2962b0b0b 100644
--- a/kdeprint/kdeprintfax/confgeneral.h
+++ b/kdeprint/kdeprintfax/confgeneral.h
@@ -1,5 +1,5 @@
/*
- * kdeprintfax - a small fax utility
+ * tdeprintfax - a small fax utility
* Copyright (C) 2001 Michael Goffioul
*
* This program is free software; you can redistribute it and/or modify
diff --git a/kdeprint/kdeprintfax/configdlg.h b/kdeprint/kdeprintfax/configdlg.h
index 1e312b57b..6fabd2011 100644
--- a/kdeprint/kdeprintfax/configdlg.h
+++ b/kdeprint/kdeprintfax/configdlg.h
@@ -1,5 +1,5 @@
/*
- * kdeprintfax - a small fax utility
+ * tdeprintfax - a small fax utility
* Copyright (C) 2001 Michael Goffioul
*
* This program is free software; you can redistribute it and/or modify
diff --git a/kdeprint/kdeprintfax/confsystem.cpp b/kdeprint/kdeprintfax/confsystem.cpp
index 7410a0191..91c23adb6 100644
--- a/kdeprint/kdeprintfax/confsystem.cpp
+++ b/kdeprint/kdeprintfax/confsystem.cpp
@@ -1,5 +1,5 @@
/*
- * kdeprintfax - a small fax utility
+ * tdeprintfax - a small fax utility
* Copyright (C) 2001 Michael Goffioul
*
* This program is free software; you can redistribute it and/or modify
diff --git a/kdeprint/kdeprintfax/confsystem.h b/kdeprint/kdeprintfax/confsystem.h
index 9306df9f3..0ce8971f0 100644
--- a/kdeprint/kdeprintfax/confsystem.h
+++ b/kdeprint/kdeprintfax/confsystem.h
@@ -1,5 +1,5 @@
/*
- * kdeprintfax - a small fax utility
+ * tdeprintfax - a small fax utility
* Copyright (C) 2001 Michael Goffioul
*
* This program is free software; you can redistribute it and/or modify
diff --git a/kdeprint/kdeprintfax/defcmds.cpp b/kdeprint/kdeprintfax/defcmds.cpp
index 123956377..a2d58c17e 100644
--- a/kdeprint/kdeprintfax/defcmds.cpp
+++ b/kdeprint/kdeprintfax/defcmds.cpp
@@ -1,6 +1,6 @@
/*
* This file is part of the KDE libraries
- * Copyright (c) 2001 Michael Goffioul <kdeprint@swing.be>
+ * Copyright (c) 2001 Michael Goffioul <tdeprint@swing.be>
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Library General Public
diff --git a/kdeprint/kdeprintfax/defcmds.h b/kdeprint/kdeprintfax/defcmds.h
index f76094709..90d67b83f 100644
--- a/kdeprint/kdeprintfax/defcmds.h
+++ b/kdeprint/kdeprintfax/defcmds.h
@@ -1,5 +1,5 @@
/*
- * kdeprintfax - a small fax utility
+ * tdeprintfax - a small fax utility
* Copyright (C) 2001 Michael Goffioul
*
* This program is free software; you can redistribute it and/or modify
diff --git a/kdeprint/kdeprintfax/faxab.cpp b/kdeprint/kdeprintfax/faxab.cpp
index a54375867..ad50ac9fb 100644
--- a/kdeprint/kdeprintfax/faxab.cpp
+++ b/kdeprint/kdeprintfax/faxab.cpp
@@ -1,5 +1,5 @@
/*
- * kdeprintfax - a small fax utility
+ * tdeprintfax - a small fax utility
* Copyright (C) 2001 Michael Goffioul
*
* This program is free software; you can redistribute it and/or modify
diff --git a/kdeprint/kdeprintfax/faxab.h b/kdeprint/kdeprintfax/faxab.h
index f50748217..8b50c204a 100644
--- a/kdeprint/kdeprintfax/faxab.h
+++ b/kdeprint/kdeprintfax/faxab.h
@@ -1,5 +1,5 @@
/*
- * kdeprintfax - a small fax utility
+ * tdeprintfax - a small fax utility
* Copyright (C) 2001 Michael Goffioul
*
* This program is free software; you can redistribute it and/or modify
diff --git a/kdeprint/kdeprintfax/faxctrl.h b/kdeprint/kdeprintfax/faxctrl.h
index accbd6556..a7e16a850 100644
--- a/kdeprint/kdeprintfax/faxctrl.h
+++ b/kdeprint/kdeprintfax/faxctrl.h
@@ -1,5 +1,5 @@
/*
- * kdeprintfax - a small fax utility
+ * tdeprintfax - a small fax utility
* Copyright (C) 2001 Michael Goffioul
*
* This program is free software; you can redistribute it and/or modify
@@ -25,7 +25,7 @@
#include <tqstring.h>
#include <tqstringlist.h>
-#include "kdeprintfax.h"
+#include "tdeprintfax.h"
class KProcess;
class TQTextEdit;
diff --git a/kdeprint/kdeprintfax/filterdlg.cpp b/kdeprint/kdeprintfax/filterdlg.cpp
index 5e6f018a1..0324863bc 100644
--- a/kdeprint/kdeprintfax/filterdlg.cpp
+++ b/kdeprint/kdeprintfax/filterdlg.cpp
@@ -1,5 +1,5 @@
/*
- * kdeprintfax - a small fax utility
+ * tdeprintfax - a small fax utility
* Copyright (C) 2001 Michael Goffioul
*
* This program is free software; you can redistribute it and/or modify
diff --git a/kdeprint/kdeprintfax/filterdlg.h b/kdeprint/kdeprintfax/filterdlg.h
index f0736bc88..ab4fd0406 100644
--- a/kdeprint/kdeprintfax/filterdlg.h
+++ b/kdeprint/kdeprintfax/filterdlg.h
@@ -1,5 +1,5 @@
/*
- * kdeprintfax - a small fax utility
+ * tdeprintfax - a small fax utility
* Copyright (C) 2001 Michael Goffioul
*
* This program is free software; you can redistribute it and/or modify
diff --git a/kdeprint/kdeprintfax/kdeprintfax.desktop b/kdeprint/kdeprintfax/kdeprintfax.desktop
index a33f9292f..dc9c90bab 100644
--- a/kdeprint/kdeprintfax/kdeprintfax.desktop
+++ b/kdeprint/kdeprintfax/kdeprintfax.desktop
@@ -90,8 +90,8 @@ GenericName[zh_TW]=傳真工具
GenericName[zu]=Isisebenzi se-Fax
Type=Application
-Exec=kdeprintfax -caption "%c" %i %m %u
-Icon=kdeprintfax
+Exec=tdeprintfax -caption "%c" %i %m %u
+Icon=tdeprintfax
Terminal=false
X-DCOP-ServiceType=Multi
Categories=Qt;KDE;Utility;X-KDE-Utilities-Peripherals;
diff --git a/kdeprint/kdeprintfax/kdeprintfax.h b/kdeprint/kdeprintfax/kdeprintfax.h
index ac54d8b61..fc1a02f7f 100644
--- a/kdeprint/kdeprintfax/kdeprintfax.h
+++ b/kdeprint/kdeprintfax/kdeprintfax.h
@@ -1,5 +1,5 @@
/*
- * kdeprintfax - a small fax utility
+ * tdeprintfax - a small fax utility
* Copyright (C) 2001 Michael Goffioul
*
* This program is free software; you can redistribute it and/or modify
diff --git a/kdeprint/kdeprintfax/kdeprintfaxui.rc b/kdeprint/kdeprintfax/kdeprintfaxui.rc
index 09c2be6f2..ae233a6da 100644
--- a/kdeprint/kdeprintfax/kdeprintfaxui.rc
+++ b/kdeprint/kdeprintfax/kdeprintfaxui.rc
@@ -1,5 +1,5 @@
<!DOCTYPE kpartgui>
-<kpartgui name="kdeprintfax">
+<kpartgui name="tdeprintfax">
<MenuBar>
<Menu name="file"><text>&amp;File</text>
<Action name="file_add" />
diff --git a/kdeprint/kdeprintfax/conffilters.cpp b/kdeprint/kdeprintfax/conffilters.cpp
index 7f33136d9..d32f33ea8 100644
--- a/kdeprint/kdeprintfax/conffilters.cpp
+++ b/kdeprint/kdeprintfax/conffilters.cpp
@@ -1,5 +1,5 @@
/*
* kdeprintfax - a small fax utility
* Copyright (C) 2001 Michael Goffioul
*
* This program is free software; you can redistribute it and/or modify
@@ -85,7 +85,7 @@ ConfFilters::ConfFilters(TQWidget *parent, const char *name)
void ConfFilters::load()
{
- TQFile f(locate("data","kdeprintfax/faxfilters"));
+ TQFile f(locate("data","tdeprintfax/faxfilters"));
if (f.exists() && f.open(IO_ReadOnly))
{
TQTextStream t(&f);
@@ -108,7 +108,7 @@ void ConfFilters::load()
void ConfFilters::save()
{
TQListViewItem *item = m_filters->firstChild();
- TQFile f(locateLocal("data","kdeprintfax/faxfilters"));
+ TQFile f(locateLocal("data","tdeprintfax/faxfilters"));
if (f.open(IO_WriteOnly))
{
TQTextStream t(&f);
@@ -1,5 +1,5 @@
/*
- * kdeprintfax - a small fax utility
+ * tdeprintfax - a small fax utility
* Copyright (C) 2001 Michael Goffioul
*
diff --git a/kdeprint/kdeprintfax/configdlg.cpp b/kdeprint/kdeprintfax/configdlg.cpp
index a3616cf54..526b767ff 100644
--- a/kdeprint/kdeprintfax/configdlg.cpp
+++ b/kdeprint/kdeprintfax/configdlg.cpp
@@ -1,5 +1,5 @@
/*
* kdeprintfax - a small fax utility
* Copyright (C) 2001 Michael Goffioul
*
* This program is free software; you can redistribute it and/or modify
@@ -37,7 +37,7 @@ ConfigDlg::ConfigDlg(TQWidget *parent, const char *name)
TQVBox *page2 = addVBoxPage(i18n("Page setup"), i18n("Page Setup"), DesktopIcon("editcopy"));
m_fax = new ConfFax(page2, "Fax");
- TQVBox *page3 = addVBoxPage(i18n("System"), i18n("Fax System Selection"), DesktopIcon("kdeprintfax"));
+ TQVBox *page3 = addVBoxPage(i18n("System"), i18n("Fax System Selection"), DesktopIcon("tdeprintfax"));
m_system = new ConfSystem(page3, "System");
TQVBox *page4 = addVBoxPage(i18n("Filters"), i18n("Filters Configuration"), DesktopIcon("filter"));
@@ -1,5 +1,5 @@
/*
- * kdeprintfax - a small fax utility
+ * tdeprintfax - a small fax utility
* Copyright (C) 2001 Michael Goffioul
*
diff --git a/kdeprint/kdeprintfax/faxctrl.cpp b/kdeprint/kdeprintfax/faxctrl.cpp
index eed9d5816..c1b1b1a0d 100644
--- a/kdeprint/kdeprintfax/faxctrl.cpp
+++ b/kdeprint/kdeprintfax/faxctrl.cpp
@@ -1,5 +1,5 @@
/*
* kdeprintfax - a small fax utility
* Copyright (C) 2001 Michael Goffioul
*
* This program is free software; you can redistribute it and/or modify
@@ -19,7 +19,7 @@
*/
#include "faxctrl.h"
-#include "kdeprintfax.h"
+#include "tdeprintfax.h"
#include "defcmds.h"
#include <ktextedit.h>
@@ -486,11 +486,11 @@ void FaxCtrl::filter()
}
else
{
- TQString tmp = locateLocal("tmp","kdeprintfax_") + kapp->randomString(8);
+ TQString tmp = locateLocal("tmp","tdeprintfax_") + kapp->randomString(8);
m_filteredfiles.prepend(tmp);
m_tempfiles.append(tmp);
m_process->clearArguments();
- *m_process << locate("data","kdeprintfax/anytops") << "-m" << KProcess::quote(locate("data","kdeprintfax/faxfilters"))
+ *m_process << locate("data","tdeprintfax/anytops") << "-m" << KProcess::quote(locate("data","tdeprintfax/faxfilters"))
<< TQString::tqfromLatin1("--mime=%1").arg(mimeType)
<< "-p" << pageSize()
<< KProcess::quote(m_files[0]) << KProcess::quote(tmp);
@@ -1,5 +1,5 @@
/*
- * kdeprintfax - a small fax utility
+ * tdeprintfax - a small fax utility
* Copyright (C) 2001 Michael Goffioul
*
diff --git a/kdeprint/kdeprintfax/kdeprintfax.cpp b/kdeprint/kdeprintfax/kdeprintfax.cpp
index 0b0e59b6b..24ad58a0e 100644
--- a/kdeprint/kdeprintfax/kdeprintfax.cpp
+++ b/kdeprint/kdeprintfax/kdeprintfax.cpp
@@ -1,5 +1,5 @@
/*
* kdeprintfax - a small fax utility
* Copyright (C) 2001 Michael Goffioul
*
* This program is free software; you can redistribute it and/or modify
@@ -18,7 +18,7 @@
*
*/
-#include "kdeprintfax.h"
+#include "tdeprintfax.h"
#include "faxab.h"
#include "faxctrl.h"
#include "configdlg.h"
@@ -106,7 +106,7 @@ KdeprintFax::KdeprintFax(TQWidget *parent, const char *name)
connect( m_delbtn, TQT_SIGNAL( clicked() ), TQT_SLOT( slotFaxRemove() ) );
TQLabel *m_commentlabel = new TQLabel(i18n("&Comment:"), mainw);
KSystemTray *m_tray = new KSystemTray(this);
- m_tray->setPixmap(SmallIcon("kdeprintfax"));
+ m_tray->setPixmap(SmallIcon("tdeprintfax"));
m_tray->show();
m_comment = new TQTextEdit(mainw);
// I don't understand why anyone would want to turn off word wrap. It makes
@@ -604,4 +604,4 @@ bool KdeprintFax::manualFaxDialog( TQString& number, TQString& name, TQString& e
return false;
}
-#include "kdeprintfax.moc"
+#include "tdeprintfax.moc"
@@ -1,5 +1,5 @@
/*
- * kdeprintfax - a small fax utility
+ * tdeprintfax - a small fax utility
* Copyright (C) 2001 Michael Goffioul
*
diff --git a/kdeprint/kdeprintfax/main.cpp b/kdeprint/kdeprintfax/main.cpp
index c1a92fd12..4fe22a3b6 100644
--- a/kdeprint/kdeprintfax/main.cpp
+++ b/kdeprint/kdeprintfax/main.cpp
@@ -1,5 +1,5 @@
/*
* kdeprintfax - a interface to fax-packages
* Copyright (C) 2001 Michael Goffioul
*
* This program is free software; you can redistribute it and/or modify
@@ -18,7 +18,7 @@
*
*/
-#include "kdeprintfax.h"
+#include "tdeprintfax.h"
#include <tqfile.h>
#include <kcmdlineargs.h>
@@ -30,7 +30,7 @@ TQString debugFlag;
int oneShotFlag = false;
static const char description[] =
- I18N_NOOP("A small fax utility to be used with kdeprint.");
+ I18N_NOOP("A small fax utility to be used with tdeprint.");
// INSERT A DESCRIPTION FOR YOUR APPLICATION HERE
@@ -47,10 +47,10 @@ static KCmdLineOptions options[] =
int main(int argc, char *argv[])
{
- KAboutData aboutData( "kdeprintfax", I18N_NOOP("KdeprintFax"),
+ KAboutData aboutData( "tdeprintfax", I18N_NOOP("KdeprintFax"),
"1.0", description, KAboutData::License_GPL,
"(c), 2001 Michael Goffioul", 0, "http://printing.kde.org");
- aboutData.addAuthor("Michael Goffioul",0, "kdeprint@swing.be");
+ aboutData.addAuthor("Michael Goffioul",0, "tdeprint@swing.be");
KCmdLineArgs::init( argc, argv, &aboutData );
KCmdLineArgs::addCmdLineOptions( options ); // Add our own options.
KApplication::addCmdLineOptions();
@@ -1,5 +1,5 @@
/*
- * kdeprintfax - a interface to fax-packages
+ * tdeprintfax - a interface to fax-packages
* Copyright (C) 2001 Michael Goffioul
*